@@ -285,9 +285,6 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
     heatmap_Colocalization = np.zeros((len(CropConf),int(len(Marker_Names)*(len(Marker_Names)-1)/2))) # Number of TMEs x Number of Marker combinations
     heatmap_CellSize_circularity = np.zeros((len(CropConf),2)) # Number of TMEs x (size and circularity)
 
-    # Mean marker expression and std marker expression
-    # AllCELLLS = np.concatenate([np.stack([c[0].mean((0,1)) for c in CC]) for CC in CropConf if len(CC)>0])
-
     # Use CropCOnf, that saves a lot of patches...
     for n_cell_type ,CropConf_i in enumerate(CropConf):
         
@@ -298,7 +295,6 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
         topkPheno = np.array([CCP[1] for CCP in CropConf_i]).argsort()[-k:]        
         # Save topkPheno to heatMarkerMap. Mean
         MarkerExpression = np.array([CropConf_i[t][0] for t in topkPheno])
-        Confidence = np.array([CropConf_i[t][1] for t in topkPheno])
 
         heatmap_Colocalization[n_cell_type,:] = calculate_marker_colocalization(MarkerExpression,Marker_Names)
         try:
@@ -306,10 +302,6 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
         except:
             print('could not calculate cell size circularity because DAPI marker is missing')
 
-        # Save marker expression of patches individually.
-        # save_2Dmatrix_in_excel_with_names(thisfolder+'TME_{}_Conf_{}.xlsx'.format(n_cell_type+1,Confidence.mean().round(2)),MarkerExpression.mean((1,2)),Marker_Names)
-        # save_heatmap_with_names(thisfolder+'TME_{}_Conf_{}.png'.format(n_cell_type+1,Confidence.mean().round(2)),(MarkerExpression.mean((1,2))-AllCELLLS.mean(0))/AllCELLLS.std(0),Marker_Names)
-
         MarkerExpression = np.reshape(MarkerExpression,(MarkerExpression.shape[0]*MarkerExpression.shape[1]*MarkerExpression.shape[2],MarkerExpression.shape[3]))
         heatmapMarkerExpression[0,n_cell_type,:] = np.mean(MarkerExpression,axis=0)                    
         for n_i, i in enumerate(Thresholds[1:]):
@@ -317,14 +309,12 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
 
         # Save Image in RGB
         ImwithKPatches = np.zeros((dataset.patch_size*mult_1*int(np.sqrt(k))+mult_2*int(np.sqrt(k)),dataset.patch_size*mult_1*int(np.sqrt(k))+mult_2*int(np.sqrt(k)),CropConf_i[0][0].shape[2]))
-        ImwithKPatches_Norm_perPatch = np.zeros((dataset.patch_size*mult_1*int(np.sqrt(k))+mult_2*int(np.sqrt(k)),dataset.patch_size*mult_1*int(np.sqrt(k))+mult_2*int(np.sqrt(k)),CropConf_i[0][0].shape[2]))
         for t_n, t in enumerate(topkPheno):
             row = np.floor(t_n/int(k**0.5))
             col = np.mod(t_n,int(k**0.5))
        
             # Assign patch to Image
             ImwithKPatches[int(row*mult_1*dataset.patch_size+row*mult_2):int((row+1)*mult_1*dataset.patch_size+row*mult_2),int(col*mult_1*dataset.patch_size+col*mult_2):int((col+1)*mult_1*dataset.patch_size+col*mult_2),:] = CropConf_i[t][0]
-            ImwithKPatches_Norm_perPatch[int(row*mult_1*dataset.patch_size+row*mult_2):int((row+1)*mult_1*dataset.patch_size+row*mult_2),int(col*mult_1*dataset.patch_size+col*mult_2):int((col+1)*mult_1*dataset.patch_size+col*mult_2),:] = CropConf_i[t][0]/CropConf_i[t][0].max((0,1),keepdims=True)
         
         if len(Marker_Names)<10:
             # Fill unassigned patches with zeroes.
@@ -333,11 +323,9 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
                 col = np.mod(t_n,int(k**0.5))
                 # Assign patch to Image
                 ImwithKPatches[int(row*mult_1*dataset.patch_size+row*mult_2):int((row+1)*mult_1*dataset.patch_size+row*mult_2),int(col*mult_1*dataset.patch_size+col*mult_2):int((col+1)*mult_1*dataset.patch_size+col*mult_2),:] = 0.0
-                ImwithKPatches_Norm_perPatch[int(row*mult_1*dataset.patch_size+row*mult_2):int((row+1)*mult_1*dataset.patch_size+row*mult_2),int(col*mult_1*dataset.patch_size+col*mult_2):int((col+1)*mult_1*dataset.patch_size+col*mult_2),:] = 0.0
                             
             # RGBImwithKPatches = dataset.nPlex2RGB(ImwithKPatches)
             imwrite(thisfolder+'Cell_type_{}_Raw.tiff'.format(n_cell_type+1),np.moveaxis(ImwithKPatches,2,0))
-            imwrite(thisfolder+'Cell_type_{}_Patch_Norm.tiff'.format(n_cell_type+1),np.moveaxis(ImwithKPatches_Norm_perPatch,2,0))
             
             # Save Certainty of this Phenotype
             plt.close()
@@ -547,4 +535,4 @@ def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, Clustering
     Area_to_Neigh[np.isnan(Area_to_Neigh)] = 0
     h_E_Fig = sns.clustermap(Area_to_Neigh.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Area,
                                 row_colors=col_colors_Neigh,yticklabels=xticklabels_Neigh,xticklabels=yticklabels_Area, linewidths=0.5, cmap="bwr")            
-    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Areas/heatmap_Neighborhood_composition_of_Areas_Perc.png',dpi=600) 
+    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'heatmap_Neighborhood_composition_of_Areas_Perc.png',dpi=600) 
