@@ -701,13 +701,13 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         else:
             # Load Image in its own format.
             if os.listdir(self.root+'Raw_Data/Images/')[-1].split('.')[-1]=='tiff':
-                im = tifffile.imread(self.root+'Raw_Data/Images/'+idxclster[0]+'.tiff')                 
+                im = tifffile.imread(self.root+'Raw_Data/Images/'+idxclster[0])                 
             elif os.listdir(self.root+'Raw_Data/Images/')[-1].split('.')[-1]=='tif' and os.listdir(self.root+'Raw_Data/Images/')[-1].split('.')[-2]=='ome':
                 im = tifffile.imread(self.root+'Raw_Data/Images/'+idxclster[0])
                 im -= im.min()
                 im = ((im/im.max())*255).astype(np.uint8)
             elif os.listdir(self.root+'Raw_Data/Images/')[-1].split('.')[-1]=='tif':
-                im = tifffile.imread(self.root+'Raw_Data/Images/'+idxclster[0]+'.tif') 
+                im = tifffile.imread(self.root+'Raw_Data/Images/'+idxclster[0]) 
             elif os.listdir(self.root+'Raw_Data/Images/')[-1].split('.')[-1]=='npy':
                 im = np.load(self.root+'Raw_Data/Images/'+idxclster[0]+'.npy')
             if len(im.shape)==3:
