@@ -160,9 +160,13 @@ class ContrastiveLearningDataset_PCL(Dataset):
             min_im = aug.min((0,1))
             aug = aug-min_im
             max_im = aug.max((0,1))
-            aug = aug/max_im*255        
-            aug = rgb_perturb_stain_concentration(aug)
-            aug = (((aug*max_im)/255)+min_im)
+            max_im[max_im<=0] = 1e-16
+            aug = aug/max_im*255     
+            try:
+                aug = rgb_perturb_stain_concentration(aug.astype(np.uint8))
+                aug = (((aug*max_im)/255)+min_im)
+            except:
+                aug = (((aug*max_im)/255)+min_im)
         
         # Define sequence of augmentations
         seq_easy = iaa.Sequential([
@@ -181,8 +185,13 @@ class ContrastiveLearningDataset_PCL(Dataset):
             for c in range(aug.shape[2]):
                 aug[:,:,c] = np.flip(aug[:,:,c],1)
 
-        # Color_Distortion...->...Sobel...->...Gaussian_Noise...->...Rotate        
-        return seq_easy(images=aug.astype(np.float32))    
+        # RGB
+        if aug.shape[2]==3:
+            return seq_easy(image=aug.astype(np.float32))    
+        
+        # Multiplex
+        else:
+            return seq_easy(images=aug.astype(np.float32))    
 
     def __getitem__(self, idx):
         if torch.is_tensor(idx):
