@@ -13,38 +13,89 @@ import numpy as np
 from PIL import Image
 from sklearn.cluster import AgglomerativeClustering
 import gc 
+from openTSNE import TSNE
+from sklearn.preprocessing import StandardScaler
+from matplotlib import pyplot as plt
+import seaborn as sns
+import sklearn
 gc.set_threshold(0,0,0)
 
 torch.manual_seed(0)
 
-def visualize_using_clustering(name,features,image_size,patch_size,image):
+def visualize_using_clustering_ALL(dataset, out_dir, features, features_idx, patch_images):
 
-    # Create patch Image
-    Patch_im = np.zeros(image_size)                                
-    division_rows = np.floor(Patch_im.shape[0]/patch_size)
-    division_cols = np.floor(Patch_im.shape[1]/patch_size)
-    lins = np.repeat(list(range(int(division_cols))), patch_size)
-    lins = np.repeat(np.expand_dims(lins,axis=1), patch_size, axis=1)
-    for row_indx, row in enumerate(range(int(division_rows))):
-        Patch_im[row_indx*patch_size:(row_indx+1)*patch_size,:int(division_cols*patch_size)] = np.transpose(lins+int(row_indx*division_cols))    
-    Patch_im = Patch_im.astype(int)
+    # Cluster image using all information.
+    clusters_ALL = sklearn.cluster.KMeans(n_clusters=5).fit(features[:,2:])
+    
+    # Calculate image size
+    for im_idx, name in enumerate(patch_images):
+        
+        # # CLusters all
+        sel_feats = features[features_idx==im_idx]
+        image_size = sel_feats[:,:2].max(0)+sel_feats[:,:2].min(0)
+        patch_size = int((sel_feats[:,:2].min(0)*2)[0])
+        sel_clusters_all = clusters_ALL.labels_[features_idx==im_idx]
 
-    # Cluster into distinct phenotypes
-    clustering = AgglomerativeClustering(n_clusters=3).fit(features)
-    Cluster_image = clustering.labels_[Patch_im]
+        # CLustering of this image
+        clusters_im = sklearn.cluster.KMeans(n_clusters=5).fit(sel_feats[:,2:])
+        
+        # Create patch Image
+        Patch_im = np.zeros((int(image_size[0]),int(image_size[1])))                        
+        # Create superPatch Label image using the Superpatch size. 
+        division_rows = np.floor(Patch_im.shape[0]/patch_size)
+        division_cols = np.floor(Patch_im.shape[1]/patch_size)
+        lins = np.repeat(list(range(int(division_cols))), patch_size)
+        lins = np.repeat(np.expand_dims(lins,axis=1), patch_size, axis=1)
+        for row_indx, row in enumerate(range(int(division_rows))):
+            Patch_im[row_indx*patch_size:(row_indx+1)*patch_size,:int(division_cols*patch_size)] = np.transpose(lins+int(row_indx*division_cols))
+        Patch_im = Patch_im.astype(int)
 
-    # Save patch Image
-    imtosave = Image.fromarray(np.uint16(Patch_im))
-    imtosave.save(name+'_PatchIm.png')                
+        # Cluster into distinct phenotypes
+        Cluster_image_ALL = sel_clusters_all[Patch_im]
+        Cluster_image = clusters_im.labels_[Patch_im]
 
-    # Save cluster image
-    imtosave = Image.fromarray(np.uint8(Cluster_image))
-    imtosave.save(name+'_cluster.png') 
+        # Save cluster image
+        imtosave = Image.fromarray(np.uint8(Cluster_image_ALL))
+        imtosave.save(out_dir+name+'_cluster_ALL.png') 
 
-    # Save image    
-    imtosave = Image.fromarray(np.uint16((image.squeeze()[:,:,6].numpy()/image.squeeze()[:,:,6].numpy().max())*65550))
-    imtosave.save(name+'_image.png')                
+        # Save cluster image
+        imtosave = Image.fromarray(np.uint8(Cluster_image))
+        imtosave.save(out_dir+name+'_cluster.png') 
 
+def visualize_batch_effect_Ph(out_dir,features,features_idx,count):
+    
+    # Select n subjects randomly
+    num_subjects = 5
+    sel_subjects = sum(([features_idx==c for c in np.random.randint(0, high=features_idx.max(),size=num_subjects)]))>0
+    features_idx = features_idx[sel_subjects]
+    features = features[sel_subjects]
+    
+    # Select number of patches
+    num_val = 100000    
+    features_idx = features_idx[::int(features_idx.shape[0]/num_val)]
+    features = features[::int(features.shape[0]/num_val),:]
+
+    # Reorder samples
+    sel_vals = np.random.randint(0,high=features.shape[0],size=features.shape[0])
+    features = features[sel_vals]
+    features_idx = features_idx[sel_vals]
+
+    # Normalize features
+    scaled_features = StandardScaler().fit_transform(features[:,2:])
+
+    # Create UMAP
+    embedding = TSNE().fit(scaled_features)
+
+    # Create and save scatter plot figure
+    plt.close()
+    fig, ax = plt.subplots()   
+    scatter = ax.scatter(embedding[:, 0],embedding[:, 1],s=2,c=features_idx,cmap="gist_rainbow")
+    legend1 = ax.legend(*scatter.legend_elements(),loc="upper right", title="Subjects")
+    ax.add_artist(legend1)
+    plt.title('TSNE of the dataset - one pat', fontsize=24)    
+    plt.savefig(out_dir+'/TSNE_embeddings_Patients_'+str(count)+'.png',dpi=600)
+
+    return
 
 class SimCLR(object):
 
@@ -221,8 +272,81 @@ class SimCLR(object):
             
             
             # visualize_using_clustering(folder+filename[0],features,[1200,1200],patches.shape[2],image)
-            
-            
-            
 
         return 
+
+
+    def cluster_patches(self, patch_dir, out_dir):
+        
+        # Patches from subjects
+        patch_images = os.listdir(patch_dir)        
+
+        features = []
+        features_idx = []
+
+        # Extract patches and save it into a graph
+        for subj_idx, filename in enumerate(patch_images):                                    
+            
+            # Load image 
+            subject_feats = np.load(patch_dir+filename)
+
+            # Store feats
+            features.append(subject_feats)
+            
+            # Store subject idx
+            features_idx.append([subj_idx]*subject_feats.shape[0])
+
+        # Store in one file all features
+        features = np.concatenate(features,axis=0)
+        features_idx = np.concatenate(features_idx,axis=0)        
+
+        # Show batch effect        
+        # visualize_batch_effect_Ph(out_dir,features,features_idx,0)
+
+        # Cluster image 
+        visualize_using_clustering_ALL(self, out_dir, features, features_idx, patch_images)
+
+
+
+            # # Save features
+            # features = np.concatenate((np.squeeze(patch_pos),features),axis=1)    
+
+            # # Join several images to one numpy structure
+            # patient_to_image = [i for i in os.listdir(self.args['path']+'Raw_Data/Experiment_Information/') if 'Patient_to_Image.xlsx'==i]
+            # if len(patient_to_image)>0:
+                
+            #     # Find subject name and subject file
+            #     patient_to_image_excel = pd.read_excel(self.args['path']+'Raw_Data/Experiment_Information/'+patient_to_image[0])
+            #     index = list(patient_to_image_excel['Image_Name']).index(filename[0])
+            #     NPYname = self.folder+patient_to_image_excel['Subject_Name'][index]+'.npy'
+                
+            #     # if already exists...                 
+            #     if os.path.isfile(NPYname):
+                    
+            #         # Load previous concatenate with actual data and save it.
+            #         prevFeats = np.load(NPYname)
+            #         features[:,:2] = features[:,:2] + prevFeats[:,:2].max() + self.args['PCL_Patch_Size']*10 
+            #         np.save(NPYname,np.concatenate((prevFeats,features),axis=0))      
+            #         del prevFeats           
+
+            #     else:
+
+            #         # Create new file
+            #         np.save(NPYname,features)    
+                
+            # # Save one image is one subject
+            # else:
+            #     np.save(self.folder+filename[0],features)    
+            #     # tifffile.imsave(self.folder+filename[0]+'##.tiff',np.stack([np.reshape(features[:,i],(289,240)) for i in range(features.shape[1])]))
+
+
+            # # Eliminate data from garbage collector
+            # del patches, patch_pos, filename, features 
+            # gc.collect(0)
+            # gc.collect(1)      
+            # gc.collect(2)      
+            
+            
+            # visualize_using_clustering(folder+filename[0],features,[1200,1200],patches.shape[2],image)
+
+        return 
\ No newline at end of file
